EduMUD
======

|PyPI| |PyPI - Downloads| |Documentation Status| |PyPI - License|

A Python package to assist in the study of sedimentation phenomena in
colloidal suspensions. The code is being developed by `Paul J.M. van
Kan <http://vankanscientific.nl>`__ for the MUDNET group at Delft
Technical University and DELTARES, The Netherlands. The EduMUD package
can be used under the conditions of the GPLv3 license.

Features
--------

* Basic classes colloidal systems
* Basic functions for DLVO theory.


Installation
------------

To use the package `edumud`, install it in a Python environment:

.. code-block:: console

    (env) pip install edumud

or

.. code-block:: console

    (env) conda install edumud

This should
automatically install the dependency packages ``matplotlib`` , ``scipy``
and ``pandas``, if they haven't been installed already. If you are
installing by hand, ensure that these packages are installed as well.

Example use
-----------

.. code:: python

   """Example Python script using the EduMUD module."""

   import numpy as np

   from edumud.constants import *
   from edumud.electrolytes import Electrolyte
   from edumud.particles import Particle
   from edumud.file_utils import load_config

   import matplotlib
   import matplotlib.pyplot as plt
   from pathlib import Path

   matplotlib.use("Qt5Agg")
   DATADIR = Path(__file__).parent

   el = Electrolyte(str(DATADIR / "cegm.yaml"))
   el.calc_kappa()

   param = load_config(str(DATADIR / "cegm.yaml"))
   part = Particle.from_dict(param["particles"][0])

   zeta_zero = BOLTZ_T / (el.z_plus * E_CHARGE)
   print(f"zeta_zero: {1000 * zeta_zero} mV")
   psi_zero = 0.5 * zeta_zero

EduMUD pages
------------

-  `Pypi <https://pypi.org/project/edumud/>`__: EduMUD Python package
-  `BitBucket <https://bitbucket.org/deltares/edumud/>`__: EduMUD source
   code
-  `ReadTheDocs <https://edumud.readthedocs.io/>`__: EduMUD
   documentation

Author and license
------------------

-  Author: Paul J.M. van Kan
-  Contact: p.j.m.vankan@tudelft.nl
-  License: `GPLv3 <https://www.gnu.org/licenses/gpl.html>`__

References
----------

-  ...

.. |PyPi| image:: https://img.shields.io/pypi/v/edumud
   :alt: PyPI

.. |PyPI - Downloads| image:: https://img.shields.io/pypi/dm/edumud
   :alt: PyPI - Downloads

.. |PyPi Status| image:: https://img.shields.io/pypi/status/edumud
   :alt: PyPI - Status

.. |Documentation Status| image:: https://readthedocs.org/projects/edumud/badge/?version=latest
   :target: https://edumud.readthedocs.io/en/latest/?badge=latest

.. |PyPI - License| image:: https://img.shields.io/pypi/l/edumud
   :alt: PyPI - License